@@ -28,13 +28,9 @@ from ip_inspector.database import (
 LOGGER = logging.getLogger("ip-inspector.cli")
 
 
-def main(args=None):
-    """The main CLI entry point."""
+def build_parser(parser: argparse.ArgumentParser):
+    """Build the CLI Argument parser."""
 
-    if not args:
-        args = sys.argv[1:]
-
-    parser = argparse.ArgumentParser(description="Inspect IP address metadata for IDR purposes")
     parser.add_argument("-d", "--debug", default=False, action="store_true", help="Turn on debug logging.")
     parser.add_argument(
         "-u", "--update-databases", default=False, action="store_true", help="Update the MaxMind GeoLite2 Databases"
@@ -88,7 +84,6 @@ def main(args=None):
     with get_db_session() as session:
         infrastructure_context_map = get_infrastructure_context_map(session)
     context_choices = list(infrastructure_context_map.keys())
-    default_context_id = infrastructure_context_map.get(default_context_name, 1)
     parser.add_argument(
         "-c",
         "--context",
@@ -175,12 +170,30 @@ def main(args=None):
     )
 
     argcomplete.autocomplete(parser)
-    args = parser.parse_args(args)
+    return parser
+
+
+def main(args=None, parser: argparse.ArgumentParser=None):
+    """The main CLI entry point."""
 
     # configure logging
     logging.basicConfig(level=logging.INFO, format="%(asctime)s - %(name)s - [%(levelname)s] %(message)s")
     coloredlogs.install(level="INFO", logger=LOGGER)
 
+    if not args:
+        args = sys.argv[1:]
+
+    if parser is None:
+        parser = argparse.ArgumentParser(description="Inspect IP address metadata for IDR purposes")
+
+    parser = build_parser(parser)
+    args = parser.parse_args(args)
+
+    infrastructure_context_map = {}
+    default_context_name = CONFIG["default"].get("tracking_context", DEFAULT_INFRASTRUCTURE_CONTEXT_NAME)
+    with get_db_session() as session:
+        infrastructure_context_map = get_infrastructure_context_map(session)
+
     if args.debug:
         coloredlogs.install(level="DEBUG", logger=LOGGER)
 
@@ -348,9 +361,9 @@ def main(args=None):
             iip = mmi.inspect(ip, infrastructure_context=infrastructure_context_map[args.context])
             if iip:
                 if args.raw_results:
-                    print(json.dumps(iip.raw))
+                    print(json.dumps(iip.to_dict()))
                 elif args.pretty_print:
-                    pprint(iip.raw)
+                    pprint(iip.to_dict())
                 elif args.fields:
                     result_string = f"--> {iip.network_value_passed if iip.network_value_passed else iip.ip}"
                     if args.csv:
@@ -372,9 +385,9 @@ def main(args=None):
         iip = mmi.inspect(args.ip, infrastructure_context=infrastructure_context_map[args.context])
         if iip:
             if args.raw_results:
-                print(json.dumps(iip.raw))
+                print(json.dumps(iip.to_dict()))
             elif args.pretty_print:
-                pprint(iip.raw)
+                pprint(iip.to_dict())
             elif args.fields:
                 for field in args.fields:
                     print(iip.get(field))
